FCMInterface class abstract

Implementers

Constructors

FCMInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
onMessage Stream<Map<String, dynamic>>
no setter
onMessageOpenedApp Stream<Map<String, dynamic>>
no setter
onTokenRefresh Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFCMToken() Future<String?>
getInitialMessage() Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setForegroundNotificationPresentationOptions({bool alert = true, bool badge = true, bool sound = true}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited