AirflexNotifications class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addOpenMessageListener(
OpenMessageListener listener) → void -
getUserTopics(
String userId) → Future< List< TopicData> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMessage(
) → Stream< Map< String, dynamic> > -
registerAirflexNotification(
{required String userId}) → Future< void> -
removeOpenMessageListener(
OpenMessageListener listener) → void -
setForegroundNotification(
{IOSNotificationForegroundSetting iOSsetting = const IOSNotificationForegroundSetting(), required AndroidNotificationForegroundSetting androidSetting}) → Future< void> -
setTopicSubcribeStatus(
String userId, String topicCode, bool isSubcribe) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterAirflexNotification(
String userId) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- channelId → const String
- channelName → const String